@@ -19,7 +19,6 @@
 #'   stand-in variables values.
 #' @return transformed data.frame \code{data}
 #' @export
-#' @seealso \link{compute}, \link{do_if}
 #'
 #' @examples
 #' data(iris)
@@ -74,23 +73,15 @@
 #' 
 #' 
 do_repeat = function(data, ...){
+    .Deprecated("", 
+                msg = "'do_repeat' functionality is deprecated because it seems no one need it.\n
+                    If you use 'do_repeat' please file an issue at https://github.com/gdemin/expss/issues/")
     args = substitute(list(...))
     do_repeat_internal(data, args, parent = parent.frame())   
 }
 
 
 
-#' @export
-#' @name do_repeat
-.do_repeat = function (...) {
-    reference = suppressMessages(default_dataset())
-    data = ref(reference)
-    args = substitute(list(...))
-    data = do_repeat_internal(data, args, parent = parent.frame())
-    ref(reference) = data
-    invisible(data)
-
-}
 
 
 
