@@ -3,23 +3,24 @@ if(isTRUE(getOption("covr"))){
   suppressWarnings(RNGversion("3.5.0"))
   
   data(mtcars)
-  mtcars = modify(mtcars,{
-    var_lab(mpg) = "Miles/(US) gallon"
-    var_lab(cyl) = "Number of cylinders"
-    var_lab(disp) = "Displacement (cu.in.)"
-    var_lab(hp) = "Gross horsepower"
-    var_lab(drat) = "Rear axle ratio"
-    var_lab(wt) = "Weight (lb/1000)"
-    var_lab(qsec) = "1/4 mile time"
-    var_lab(vs) = "Engine"
-    val_lab(vs) = c("V-engine" = 0,
-                    "Straight engine" = 1)
-    var_lab(am) = "Transmission"
-    val_lab(am) = c(automatic = 0,
-                    manual=1)
-    var_lab(gear) = "Number of forward gears"
-    var_lab(carb) = "Number of carburetors"
-  })
+  mtcars = mtcars %>% 
+      apply_labels(
+          mpg = "Miles/(US) gallon",
+          cyl = "Number of cylinders",
+          disp = "Displacement (cu.in.)",
+          hp = "Gross horsepower",
+          drat = "Rear axle ratio",
+          wt = "Weight (lb/1000)",
+          qsec = "1/4 mile time",
+          vs = "Engine",
+          vs = c("V-engine" = 0, 
+                 "Straight engine" = 1),
+          am = "Transmission",
+          am = c(automatic = 0, 
+                 manual=1),
+          gear = "Number of forward gears",
+          carb = "Number of carburetors"
+      )
   
   
   
@@ -170,14 +171,14 @@ if(isTRUE(getOption("covr"))){
   
   
   # data(mtcars)
-  mtcars = modify(mtcars,{
-    var_lab(vs) = "Engine"
-    val_lab(vs) = c("V-engine" = 0, 
+
+    var_lab(mtcars$vs) = "Engine"
+    val_lab(mtcars$vs) = c("V-engine" = 0, 
                     "Straight engine" = 1) 
-    var_lab(am) = "Transmission"
-    val_lab(am) = c(automatic = 0, 
+    var_lab(mtcars$am) = "Transmission"
+    val_lab(mtcars$am) = c(automatic = 0, 
                     manual=1)
-  })
+ 
   
   expect_known_value(fre(mtcars$vs), "rds/fre_ex1.rds",  update = FALSE)
   expect_known_value(fre(mtcars$vs, weight = 1), "rds/fre_ex1.rds",  update = FALSE)
@@ -401,17 +402,24 @@ if(isTRUE(getOption("covr"))){
   expect_known_value(cro_fun(iris[,-5], list(iris$Species, total()), fun = median), "rds/cro_fun8.rds",  update = FALSE)
   
   # data(mtcars)
-  mtcars = modify(mtcars,{
-    var_lab(vs) = "Engine"
-    val_lab(vs) = c("V-engine" = 0, 
-                    "Straight engine" = 1) 
-    var_lab(disp) = "Displacement (cu.in.)"
-    var_lab(hp) = "Gross horsepower"
-    var_lab(mpg) = "Miles/(US) gallon"
-    var_lab(am) = "Transmission"
-    val_lab(am) = c(automatic = 0, 
-                    manual=1)
-  })
+  mtcars = mtcars %>% 
+      apply_labels(
+          mpg = "Miles/(US) gallon",
+          cyl = "Number of cylinders",
+          disp = "Displacement (cu.in.)",
+          hp = "Gross horsepower",
+          drat = "Rear axle ratio",
+          wt = "Weight (lb/1000)",
+          qsec = "1/4 mile time",
+          vs = "Engine",
+          vs = c("V-engine" = 0, 
+                 "Straight engine" = 1),
+          am = "Transmission",
+          am = c(automatic = 0, 
+                 manual=1),
+          gear = "Number of forward gears",
+          carb = "Number of carburetors"
+      )
   
   
   expect_known_value(
@@ -542,7 +550,7 @@ if(isTRUE(getOption("covr"))){
   b = c(NA, NA, NA, 1, 1)
   expect_known_value(cro_mean(a, list(b, total())), "rds/cro_mean1.rds",  update = FALSE)
   expect_known_value(cro_sum(a, list(b, total())), "rds/cro_sum1.rds",  update = FALSE)
-  expect_known_value(calc_cro_sum(sheet(a, b), a, list(b, total())), 
+  expect_known_value(cross_sum(sheet(a, b), a, list(b, total())), 
                      "rds/cro_sum1.rds",  update = FALSE)
   expect_known_value(cro_median(a, list(b, total())), "rds/cro_median1.rds",  update = FALSE)
   
@@ -552,7 +560,7 @@ if(isTRUE(getOption("covr"))){
   
   expect_known_value(cro_mean(b, list(a, total())), "rds/cro_mean2.rds",  update = FALSE)
   expect_known_value(cro_median(b, list(a, total())), "rds/cro_median2.rds",  update = FALSE)
-  expect_known_value(calc_cro_median(sheet(a, b), b, list(a, total())), "rds/cro_median2.rds",  update = FALSE)
+  expect_known_value(cross_median(sheet(a, b), b, list(a, total())), "rds/cro_median2.rds",  update = FALSE)
   
   weight = rep(1, 5)
   expect_known_value(cro_mean(b, list(a, total()), weight = weight), "rds/cro_mean2.rds",  update = FALSE)
@@ -578,7 +586,7 @@ if(isTRUE(getOption("covr"))){
   
   
   expect_known_value(cro_median(iris[,-5], list(iris$Species, total())), "rds/cro_median8.rds",  update = FALSE)
-  expect_known_value(calc_cro_median(iris, ..[!perl("Species")], list(Species, total())), 
+  expect_known_value(cross_median(iris, ..[!perl("Species")], list(Species, total())), 
                      "rds/cro_median8.rds",  update = FALSE)
   expect_known_value(cro_median(iris[,-5], list(iris$Species, total()), weight = rep(1, 150)),
                      "rds/cro_median8.rds",  update = FALSE)
@@ -590,7 +598,7 @@ if(isTRUE(getOption("covr"))){
   
   
   expect_known_value(cro_sum(iris[,-5], list(iris$Species, total())), "rds/cro_sum8.rds",  update = FALSE)
-  expect_known_value(calc_cro_sum(iris, ..[!perl("Species")], list(Species, total())), 
+  expect_known_value(cross_sum(iris, ..[!perl("Species")], list(Species, total())), 
                      "rds/cro_sum8.rds",  update = FALSE)
   
   expect_known_value(cro_fun(iris[,-5], list(iris$Species, total()), fun = mean), "rds/cro_mean8.rds",  update = FALSE)
@@ -630,29 +638,37 @@ if(isTRUE(getOption("covr"))){
   
   context("table_summary methods")
   # data(mtcars)
-  mtcars = modify(mtcars,{
-    var_lab(vs) = "Engine"
-    val_lab(vs) = c("V-engine" = 0, 
-                    "Straight engine" = 1) 
-    var_lab(hp) = "Gross horsepower"
-    var_lab(mpg) = "Miles/(US) gallon"
-    var_lab(am) = "Transmission"
-    val_lab(am) = c(automatic = 0, 
-                    manual=1)
-  })
+  mtcars = mtcars %>% 
+      apply_labels(
+          mpg = "Miles/(US) gallon",
+          cyl = "Number of cylinders",
+          disp = "Displacement (cu.in.)",
+          hp = "Gross horsepower",
+          drat = "Rear axle ratio",
+          wt = "Weight (lb/1000)",
+          qsec = "1/4 mile time",
+          vs = "Engine",
+          vs = c("V-engine" = 0, 
+                 "Straight engine" = 1),
+          am = "Transmission",
+          am = c(automatic = 0, 
+                 manual=1),
+          gear = "Number of forward gears",
+          carb = "Number of carburetors"
+      )
   expect_known_value(cro_mean(mtcars$mpg, list(unvr(mtcars$am), total()))[,"manual"],
                      "rds/mean_methods_1.rds",  update = FALSE)
   expect_known_value(cro_fun(list(mtcars$mpg), list(unvr(mtcars$am), total()), fun = sum)[, 1], 
                      "rds/fun_methods_1.rds",  update = FALSE)
   
-  duplicated_colnames = cro_mean(mtcars$mpg, list(mtcars$am, total())) %merge% 
-    cro_mean(mtcars$mpg, list(mtcars$am, total())) 
+  duplicated_colnames = merge(cro_mean(mtcars$mpg, list(mtcars$am, total())),
+    cro_mean(mtcars$mpg, list(mtcars$am, total()))) 
   expect_known_value(duplicated_colnames[,-2], 
                      "rds/cro_methods_2.rds",  update = FALSE)
   expect_known_value(duplicated_colnames[,seq_along(duplicated_colnames)[-2]], 
                      "rds/cro_methods_2.rds",  update = FALSE)
-  duplicated_colnames = cro(mtcars$vs, list(mtcars$am, total())) %merge% 
-    cro(mtcars$vs, list(mtcars$am, total())) 
+  duplicated_colnames = merge(cro(mtcars$vs, list(mtcars$am, total())), 
+    cro(mtcars$vs, list(mtcars$am, total()))) 
   expect_known_value(duplicated_colnames[,-2], 
                      "rds/cro_methods_3.rds",  update = FALSE)
   expect_known_value(duplicated_colnames[,seq_along(duplicated_colnames)[-2]], 
